==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/app/translations/qmmp_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Jangan bersihkan daftarmain</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Mulai memainkan lagu saat ini</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Jeda lagu saat ini</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Jeda jika sedang memainkan, mainkan jika sebaliknya </translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Hentikan lagu saat ini</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Tayangkan dialog Jump to File</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Aplikasi keluar</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Setel volume pemainan (contohnya: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Cetak level volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Bungkam/Pulihkan volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Cetak status bungkam</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Lewati maju dalam daftarmain</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Lewati mundur dalam daftarmain</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Tampakkan/sembunyikan aplikasi</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Tampakkan jendela utama</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Tayangkan dialog Tambah File</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Tayangkan dialog Tambah Direktori</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="113"/>
        <source>Unknown command</source>
        <translation>Perintah tak diketahui</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="413"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Penggunaan: qmmp [pilihan] [file]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="414"/>
        <source>Options:</source>
        <translation>Pilihan:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="420"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Start qmmp dengan antarmuka pengguna yang ditentukan</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="421"/>
        <source>List all available user interfaces</source>
        <translation>Daftar semua antarmuka pengguna yang tersedia</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="422"/>
        <source>Don&apos;t start the application</source>
        <translation>Jangan mulaikan aplikasi</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="423"/>
        <source>Display this text and exit</source>
        <translation>Tayangkan teks ini dan keluar</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="424"/>
        <source>Print version number and exit</source>
        <translation>Cetak nomor versi dan keluar</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="426"/>
        <source>Home page: %1</source>
        <translation>Beranda: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="427"/>
        <source>Development page: %1</source>
        <translation>Halaman pengembang: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="428"/>
        <source>Bug tracker: %1</source>
        <translation>Pelacak bug: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="135"/>
        <location filename="../qmmpstarter.cpp" line="433"/>
        <source>Command Line Help</source>
        <translation>Bantuan Baris Perintah</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="446"/>
        <source>QMMP version: %1</source>
        <translation>Versi QMMP: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="447"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Dikompilasi dengan versi Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="448"/>
        <source>Using Qt version: %1</source>
        <translation>Menggunakan versi Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="451"/>
        <source>Qmmp Version</source>
        <translation>Versi Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="468"/>
        <source>User Interfaces</source>
        <translation>Antarmuka Pengguna</translation>
    </message>
</context>
</TS>

==> qmmp-2.1.2-1.src.tar.gz: qmmp-2.1.2/src/app/translations/qmmp_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Jangan bersihkan daftarmain</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Mulai memainkan lagu saat ini</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Jeda lagu saat ini</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Jeda jika sedang memainkan, mainkan jika sebaliknya </translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Hentikan lagu saat ini</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Tayangkan dialog Jump to File</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Aplikasi keluar</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Setel volume pemutaran (contohnya: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>Cetak level volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>Bungkam/Pulihkan volume</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>Cetak status bungkam</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>Lewati maju dalam daftarmain</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>Lewati mundur dalam daftarmain</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>Tampakkan/sembunyikan aplikasi</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>Tampakkan jendela utama</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>Tayangkan dialog Tambah File</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>Tayangkan dialog Tambah Direktori</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="121"/>
        <source>Unknown command</source>
        <translation>Perintah tak diketahui</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="438"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Penggunaan: qmmp [pilihan] [file]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="439"/>
        <source>Options:</source>
        <translation>Pilihan:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="445"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>Start qmmp dengan antarmuka pengguna yang ditentukan</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="446"/>
        <source>List all available user interfaces</source>
        <translation>Daftar semua antarmuka pengguna yang tersedia</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="447"/>
        <source>Don&apos;t start the application</source>
        <translation>Jangan mulaikan aplikasi</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="448"/>
        <source>Display this text and exit</source>
        <translation>Tayangkan teks ini dan keluar</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="449"/>
        <source>Print version number and exit</source>
        <translation>Cetak nomor versi dan keluar</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="451"/>
        <source>Home page: %1</source>
        <translation>Beranda: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="452"/>
        <source>Development page: %1</source>
        <translation>Halaman pengembang: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="453"/>
        <source>Bug tracker: %1</source>
        <translation>Pelacak bug: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="143"/>
        <location filename="../qmmpstarter.cpp" line="458"/>
        <source>Command Line Help</source>
        <translation>Bantuan Baris Perintah</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="471"/>
        <source>QMMP version: %1</source>
        <translation>Versi QMMP: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="472"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Dikompilasi dengan versi Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="473"/>
        <source>Using Qt version: %1</source>
        <translation>Menggunakan versi Qt: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="476"/>
        <source>Qmmp Version</source>
        <translation>Versi Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="493"/>
        <source>User Interfaces</source>
        <translation>Antarmuka Pengguna</translation>
    </message>
</context>
</TS>
